@@ -1,6 +1,8 @@
+from .bundles.resource import BundlesResource
 from .dictionaries.resource import DictionariesResource
 from .distributions.resource import DistributionsResource
 from .glossaries.resource import GlossariesResource
+from .groups.resource import GroupsResource
 from .labels.resource import LabelsResource
 from .languages.resource import LanguagesResource
 from .machine_translation_engines.resource import MachineTranslationEnginesResource
@@ -13,16 +15,21 @@ from .storages.resource import StoragesResource
 from .string_comments.resource import StringCommentsResource
 from .string_translations.resource import StringTranslationsResource
 from .tasks.resource import TasksResource
+from .teams.resource import TeamsResource
 from .translation_memory.resource import TranslationMemoryResource
 from .translation_status.resource import TranslationStatusResource
 from .translations.resource import TranslationsResource
-from .users.resource import UsersResource
+from .users.resource import UsersResource, EnterpriseUsersResource
+from .vendors.resource import VendorsResource
 from .webhooks.resource import WebhooksResource
+from .workflows.resource import WorkflowsResource
 
 __all__ = [
+    "BundlesResource",
     "DictionariesResource",
     "DistributionsResource",
     "GlossariesResource",
+    "GroupsResource",
     "LabelsResource",
     "LanguagesResource",
     "MachineTranslationEnginesResource",
@@ -36,9 +43,13 @@ __all__ = [
     "StringCommentsResource",
     "StringTranslationsResource",
     "TasksResource",
+    "TeamsResource",
     "TranslationMemoryResource",
     "TranslationStatusResource",
     "TranslationsResource",
     "UsersResource",
+    "EnterpriseUsersResource",
+    "VendorsResource",
     "WebhooksResource",
+    "WorkflowsResource",
 ]
