@@ -3,6 +3,7 @@ from typing import Dict, Optional, Type, Union
 
 from crowdin_api import api_resources
 from crowdin_api.enums import PlatformType
+from crowdin_api.exceptions import CrowdinException
 from crowdin_api.requester import APIRequester
 
 
@@ -62,6 +63,12 @@ class CrowdinClient:
 
         return self._api_requestor
 
+    @property
+    def bundles(self) -> api_resources.BundlesResource:
+        return api_resources.BundlesResource(
+            requester=self.get_api_requestor(), page_size=self.PAGE_SIZE
+        )
+
     @property
     def dictionaries(self) -> api_resources.DictionariesResource:
         return api_resources.DictionariesResource(
@@ -80,6 +87,15 @@ class CrowdinClient:
             requester=self.get_api_requestor(), page_size=self.PAGE_SIZE
         )
 
+    @property
+    def groups(self) -> api_resources.GroupsResource:
+        if not self._is_enterprise_platform:
+            raise CrowdinException(detail="Not implemented for the base API")
+
+        return api_resources.GroupsResource(
+            requester=self.get_api_requestor(), page_size=self.PAGE_SIZE
+        )
+
     @property
     def labels(self) -> api_resources.LabelsResource:
         return api_resources.LabelsResource(
@@ -154,6 +170,15 @@ class CrowdinClient:
             requester=self.get_api_requestor(), page_size=self.PAGE_SIZE
         )
 
+    @property
+    def teams(self) -> api_resources.TeamsResource:
+        if not self._is_enterprise_platform:
+            raise CrowdinException(detail="Not implemented for the base API")
+
+        return api_resources.TeamsResource(
+            requester=self.get_api_requestor(), page_size=self.PAGE_SIZE
+        )
+
     @property
     def translation_memory(self) -> api_resources.TranslationMemoryResource:
         return api_resources.TranslationMemoryResource(
@@ -179,8 +204,22 @@ class CrowdinClient:
         )
 
     @property
-    def users(self) -> api_resources.UsersResource:
-        return api_resources.UsersResource(
+    def users(self) -> Union[api_resources.UsersResource, api_resources.EnterpriseUsersResource]:
+        if self._is_enterprise_platform:
+            user_class = api_resources.EnterpriseUsersResource
+        else:
+            user_class = api_resources.UsersResource
+
+        return user_class(
+            requester=self.get_api_requestor(), page_size=self.PAGE_SIZE
+        )
+
+    @property
+    def vendors(self) -> api_resources.VendorsResource:
+        if not self._is_enterprise_platform:
+            raise CrowdinException(detail="Not implemented for the base API")
+
+        return api_resources.VendorsResource(
             requester=self.get_api_requestor(), page_size=self.PAGE_SIZE
         )
 
@@ -189,3 +228,12 @@ class CrowdinClient:
         return api_resources.WebhooksResource(
             requester=self.get_api_requestor(), page_size=self.PAGE_SIZE
         )
+
+    @property
+    def workflows(self) -> api_resources.WorkflowsResource:
+        if not self._is_enterprise_platform:
+            raise CrowdinException(detail="Not implemented for the base API")
+
+        return api_resources.WorkflowsResource(
+            requester=self.get_api_requestor(), page_size=self.PAGE_SIZE
+        )
